import { css, LitElement, html } from 'lit';

class UUIBreadcrumbsElement extends LitElement {
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("aria-label", "breadcrumb");
    this.setAttribute("role", "navigation");
  }
  handleSlotChange() {
    const breadcrumbNodes = this.querySelectorAll("uui-breadcrumb-item");
    const breadcrumbs = Array.from(breadcrumbNodes);
    if ((breadcrumbs == null ? void 0 : breadcrumbs.length) > 0) {
      breadcrumbs[breadcrumbs.length - 1].lastItem = true;
      breadcrumbs[breadcrumbs.length - 1].setAttribute("aria-current", "page");
    }
  }
  render() {
    return html`<ol id="breadcrumbs-list">
      <slot @slotchange=${this.handleSlotChange}></slot>
    </ol>`;
  }
}
UUIBreadcrumbsElement.styles = [
  css`
      :host {
        display: flex;
      }

      #breadcrumbs-list {
        display: flex;
        list-style-type: decimal;
        -webkit-margin-before: 0em;
                margin-block-start: 0em;
        -webkit-margin-after: 0em;
                margin-block-end: 0em;
        -webkit-margin-start: 0px;
                margin-inline-start: 0px;
        -webkit-margin-end: 0px;
                margin-inline-end: 0px;
        -webkit-padding-start: 0px;
                padding-inline-start: 0px;
      }
    `
];

export { UUIBreadcrumbsElement };
